@@ -14,7 +14,7 @@ from skimage.draw import circle
 from scipy.signal import find_peaks
 from skimage.restoration import denoise_tv_chambolle
 from irtemp import centikelvin_to_celsius
-from data_encoding import final_result
+
 ##########################################################################################################################################################################
 ##########################################################################################################################################################################
                                                 #######Sample detection using peaks#########
@@ -260,7 +260,7 @@ def pixel_intensity(sample_location, frames, x_name, y_name, plate_name):
 
 
 ##### Wrapping Function ######
-def pixel_temp(frames, n_columns, n_rows, path, freeze_heat):
+def pixel_temp(frames,n_columns,n_rows,freeze_heat):
     ''' 
     Function to determine the temperature of the samples and plate locations by analysing 
     pixel values and finding peaks.
@@ -296,13 +296,11 @@ def pixel_temp(frames, n_columns, n_rows, path, freeze_heat):
     temp, plate_temp = pixel_intensity(sample_location, frames, x_name = 'Row', y_name = 'Column', plate_name = 'plate_location')
     #Function to obtain the peaks in sample temperature profile
     s_peaks, s_infl = edge_detection.peak_detection(temp, plate_temp, 'Sample')
-    # Neural network classification
-    result_df = final_result(temp, plate_temp, path)
     # # Function to obtain the peaks in plate location temperature profile
     # p_peaks, p_infl = edge_detection.peak_detection(temp, plate_temp, 'Plate')
     # # Function to obtain the inflection point(melting point) from the temperature profile.
     # inf_temp = inflection_point(temp, plate_temp, s_peaks, p_peaks)
     # Dataframe with sample location (row and column coordinates) and respective inflection point.
     m_df = pd.DataFrame({'Row':sample_location.Row,'Column':sample_location.Column,'Melting point':np.asarray(s_infl)[:,0]})
-    return result_df
+    return m_df
 
